using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Samples.ServiceHosting.StorageClient;
using System.Configuration;
using System.Data.Services.Client;
using System.Diagnostics;
using System.Net;

namespace Benday.Azure.Common
{
    public class StorageInformation
    {
        public StorageInformation()
        {

        }

        private static string _tableName;

        private static StorageAccountInfo _account;
        private static TableStorage _tableStorage;

        private const int NumRetries = 3;
        private static RetryPolicy _tableRetry = ProviderRetryPolicies.RetryN(NumRetries, TimeSpan.FromSeconds(1));

        /// <summary>
        /// This is the initialization function that initializes the member
        /// variables. It also creates the Folder table in the table storage
        /// if the table has not been created. This function is only called 
        /// once in the Application_Start function in Global.asax file.
        /// </summary>
        public void Initialize(string tableName)
        {
            if (tableName == null)
            {
                throw new ArgumentNullException("tableName", "Argument cannot be null.");
            }
            else if (String.IsNullOrEmpty(tableName.Trim()) == true)
            {
                throw new ArgumentNullException("tableName", "Argument cannot be blank.");
            }

            _tableName = tableName;

            try
            {
                _account = StorageAccountInfo.GetDefaultTableStorageAccountFromConfiguration();
                _tableStorage = TableStorage.Create(_account);

                _tableStorage.TryCreateTable(_tableName);
            }
            catch (Exception e)
            {
                Log.Write(EventKind.Error, "Initialization of data service structures for folder storage failed!");
                throw new Exception("Could not create or find folder table in the data service ", e);
            }
        }

        public string TableName
        {
            get
            {
                return _tableName;
            }
        }

        public RetryPolicy RetrySettings
        {
            get
            {
                return _tableRetry;
            }
        }
    }
}
